#
# spec file for package python-xdg-base-dirs
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
%define modname xdg-base-dirs
Name:           python-xdg-base-dirs
Version:        6.0.1
Release:        2.2
Summary:        Variables defined by the XDG Base Directory Specification
License:        ISC
URL:            https://github.com/srstevenson/xdg-base-dirs
Source:         https://github.com/srstevenson/%{modname}/archive/refs/tags/%{version}.tar.gz#/%{modname}-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.10}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry-core}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
Provides:       python-xdg = %{version}-%{release}
Obsoletes:      python-xdg < %{version}-%{release}
%python_subpackages

%description
xdg is a Python module which provides the variables defined by the
XDG Base Directory Specification, to save you from duplicating the
same snippet of logic in every Python utility you write that deals
with user cache, configuration, or data files. It has no external
dependencies.

%prep
%autosetup -p1 -n %{modname}-%{version}

sed -i -e '/addopts.*--cov/d' pyproject.toml

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.md
%{python_sitelib}/xdg_base_dirs
%{python_sitelib}/xdg_base_dirs-%{version}*-info

%changelog
* Fri May 31 2024 Matej Cepl <mcepl@cepl.eu>
- Add %%{?sle15_python_module_pythons}
* Fri May 24 2024 Thomas Bechtold <thomasbechtold@jpberlin.de>
- Update to version 6.0.1:
  - This patch release no longer installs the LICENSE file into
    the site-packages directory.
- Update to version 6.0.0:
  - This major release renames xdg to xdg-base-dirs due to
    an import collision with PyXDG. If you used xdg prior
    to the rename, update by changing the dependency name
    from xdg to xdg-base-dirs and the import from xdg to
    xdg_base_dirs.
* Tue Oct 11 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 5.1.1
  * This patch release moves to using pathlib.Path.home() to get the home directory.
* Mon Nov  9 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 5.0.0:
  * No upstream changelog
* Tue Aug  4 2020 Antonio Larrosa <alarrosa@suse.com>
- Initial release of python-xdg 4.0.1
